# dictgetword

## Purpose

Find else add dictionary concept wordString to the KB dictionary hierarchy. Return the concept.

## Syntax

returnedWordConcept = dictgetword(wordString)

returnedWordConcept - type: con
wordString - type: str

## Returns

The newly created word concept. If the word cannot be added, returns 0.

## Remarks

The dictionary is a specialized part of the KB hierarchy used to store and lookup words.

## Example

See addword.

## See Also

addword, wordindex, wordpath, rmword, Knowledge Base Functions